#!/usr/bin/env node

import * as fs from 'fs-extra';
import * as child_process from 'child_process';
import * as glob from 'glob';
import * as path from 'path';
import * as yaml from 'js-yaml';

let src = 'src/sp-client';
let repoRelativePath = 'repo.json';
let dest = 'docs-ref-autogen';
let packageWhiteList = [];

// 1. prepare
fs.removeSync(dest);
fs.mkdirpSync(dest);

let tsconfigs = glob.sync(path.join(src, '**/tsconfig.json'));
let toc = [];

tsconfigs.forEach(function (tsconfig) {
    let packagePath = tsconfig.replace('tsconfig.json', 'package.json');
    generatePackageDoc(packagePath, dest);
});

toc = JSON.parse(JSON.stringify(toc));
fs.writeFileSync(dest + '/toc.yml', yaml.safeDump(toc));
process.exit(0);

function generatePackageDoc(packagePath, dest) {
    let dir = path.dirname(packagePath);
    if (!fs.existsSync(packagePath)) {
        return;
    }

    let packageName = fs.readJsonSync(packagePath).name;
    if (packageWhiteList.indexOf(packageName) >= 0) {
        console.log(packageName);
        console.log(dir);
        let sourceCodeBasePath = dir + '/src';
        if (fs.existsSync(sourceCodeBasePath)) {
            let packageDest = dest + '/' + packageName;
            fs.mkdirpSync(packageDest);
            try {
                child_process.execSync('typedoc --json ' + dir + '/api.json ' + dir + '/src --module commonjs --ignoreCompilerErrors');
                let basePath = sourceCodeBasePath.replace(src + '/', '');
                child_process.execFileSync('node', ['node_modules/type2docfx/dist/main', dir + '/api.json', packageDest]);
                if (fs.existsSync(packageDest + '/toc.yml')) {
                    let subToc = yaml.safeLoad(fs.readFileSync(packageDest + '/toc.yml').toString());
                    toc.push(subToc[0]);
                    fs.removeSync(packageDest + '/toc.yml');
                }
             } catch (e) {
                console.log(packageName + ': TypeDoc Parse Error.');
             }
        } else {
            console.log('No source file for ' + packageName);
        }
    }
}